@@ -39,6 +39,9 @@
  * binary/load-time compatible, increment MAJOR version
  *
  *
+ * 6.1 (unreleased):
+ *	http_CollectHdrSep added
+ *	VRT_purge modified (may fail a transaction, signature changed)
  * 6.0 (2017-03-15):
  *	VRT_hit_for_pass added
  *	VRT_ipcmp added
@@ -65,7 +68,7 @@
 
 #define VRT_MAJOR_VERSION	6U
 
-#define VRT_MINOR_VERSION	0U
+#define VRT_MINOR_VERSION	1U
 
 
 /***********************************************************************/
@@ -297,7 +300,7 @@ int VRT_re_match(VRT_CTX, const char *, void *re);
 const char *VRT_regsub(VRT_CTX, int all, const char *, void *, const char *);
 
 void VRT_ban_string(VRT_CTX, const char *);
-void VRT_purge(VRT_CTX, double ttl, double grace, double keep);
+unsigned VRT_purge(VRT_CTX, double ttl, double grace, double keep);
 
 void VRT_count(VRT_CTX, unsigned);
 void VRT_synth(VRT_CTX, unsigned, const char *);
@@ -355,8 +358,8 @@ struct vclref * VRT_ref_vcl(VRT_CTX, const char *);
 void VRT_rel_vcl(VRT_CTX, struct vclref **);
 
 void VRT_priv_fini(const struct vmod_priv *p);
-struct vmod_priv *VRT_priv_task(VRT_CTX, void *vmod_id);
-struct vmod_priv *VRT_priv_top(VRT_CTX, void *vmod_id);
+struct vmod_priv *VRT_priv_task(VRT_CTX, const void *vmod_id);
+struct vmod_priv *VRT_priv_top(VRT_CTX, const void *vmod_id);
 
 /* Stevedore related functions */
 int VRT_Stv(const char *nm);
